EventContext class

Constructors

EventContext(EventData eventData, WebSocketConnection connection)

Properties

connection ↔ WebSocketConnection
getter/setter pair
eventData ↔ EventData
getter/setter pair
eventName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, dynamic>
getter/setter pair
payload ↔ dynamic
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited