Room class
A group of connections
Properties
- connectionsNumber → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
WebSocketConnection connection, {MetaTag? metaTag}) → void - Add a connection to the room.
-
getMeta(
WebSocketConnection connection) → MetaTag? - get MetaTag from a connection if exist in the room.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
WebSocketConnection connection) → void - Remove connection and metatag from the room.
-
send(
String eventName, dynamic payload, {Map< String, dynamic> ? headers, WebSocketConnection? exclude}) → void - send a event to all room
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited